package service

import (
	"context"
	"log/slog"
)

import (
	"google.golang.org/grpc/codes"
	"google.golang.org/grpc/status"
)

import (
	"resource-server/common"
	pb "resource-server/rpc_idl/dr_resource_pb"
)

type ConfigServer struct {
	pb.UnimplementedConfigServer
}

func (s *ConfigServer) GetOptions(_ context.Context, in *pb.OptionRequest) (*pb.OptionReply, error) {
	slog.Info("Received GetOptions", "group", in.Group, "flag", in.Flag)
	res := pb.OptionReply{}
	switch in.GetGroup() {
	case "apr_cbo":
		switch in.GetFlag() {
		case "aec_filed":
			for _, v := range common.Opts.AprCbo.AECFiled {
				res.Option = append(res.Option, v.Struct())
			}
		case "compression_force":
			for _, v := range common.Opts.AprCbo.CompressionForce {
				res.Option = append(res.Option, v.Struct())
			}
		case "exposure_mode":
			for _, v := range common.Opts.AprCbo.ExposureMode {
				res.Option = append(res.Option, v.Struct())
			}
		case "focus":
			for _, v := range common.Opts.AprCbo.Focus {
				res.Option = append(res.Option, v.Struct())
			}
		case "grid_types":
			for _, v := range common.Opts.AprCbo.GridType {
				res.Option = append(res.Option, v.Struct())
			}
		case "ma":
			for _, v := range common.Opts.AprCbo.Ma {
				res.Option = append(res.Option, v.Struct())
			}
		case "ms":
			for _, v := range common.Opts.AprCbo.Ms {
				res.Option = append(res.Option, v.Struct())
			}
		}
	}
	slog.Info("Received Option", "option", &res)
	return &res, nil
}

func (s *ConfigServer) ConfigOptionList(ctx context.Context, in *pb.ConfigOptionListRequest) (*pb.ConfigOptionListReply, error) {
	product, _, _ := common.GetHeader(ctx)
	res := pb.ConfigOptionListReply{}
	switch in.GetFlag() {
	case "TimeFormat":
		//res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "TimeFormat", Text: "HH:mm:ss", Value: "HH:mm:ss", Order: 1, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "TimeFormat", Text: "HH:mm", Value: "HH:mm", Order: 2, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "TimeFormat", Text: "HH-mm-ss", Value: "HH-mm-ss", Order: 3, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "TimeFormat", Text: "HHmmss", Value: "HHmmss", Order: 4, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "TimeFormat", Text: "hh:mm:ss tt", Value: "hh:mm:ss tt", Order: 5, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "TimeFormat", Text: "h:mm:ss tt", Value: "h:mm:ss tt", Order: 6, IsEnabled: true})
	case "DateFormat":
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "DateFormat", Text: "yyyy.MM.dd", Value: "yyyy.MM.dd", Order: 1, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "DateFormat", Text: "yyyy/M/d", Value: "yyyy/M/d", Order: 2, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "DateFormat", Text: "M-d-yyyy", Value: "M-d-yyyy", Order: 3, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "DateFormat", Text: "yyyy/M/dd", Value: "yyyy/M/dd", Order: 4, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "DateFormat", Text: "yyyy-MM-dd", Value: "yyyy-MM-dd", Order: 5, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "DateFormat", Text: "M-dd-yyyy", Value: "M-dd-yyyy", Order: 6, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "DateFormat", Text: "yyyy.M.dd", Value: "yyyy.M.dd", Order: 7, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "DateFormat", Text: "yyyy/MM/dd", Value: "yyyy/MM/dd", Order: 8, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "DateFormat", Text: "MMM-dd-yyyy", Value: "MMM-dd-yyyy", Order: 9, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "DateFormat", Text: "yyyy-MMM-dd", Value: "yyyy-MMM-dd", Order: 10, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "DateFormat", Text: "dd-MMM-yyyy", Value: "dd-MMM-yyyy", Order: 11, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "DateFormat", Text: "dd.MM.yyyy", Value: "dd.MM.yyyy", Order: 12, IsEnabled: true})
	case "DoseUnit":
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "DoseUnit", Text: "rad", Value: "rad", Order: 1, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "DoseUnit", Text: "mGy", Value: "mGy", Order: 2, IsEnabled: true})
	case "WeightUnit":
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "WeightUnit", Text: "kg", Value: "kg", Order: 1, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "WeightUnit", Text: "pound", Value: "pound", Order: 2, IsEnabled: true})
	case "LengthUnit":
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "LengthUnit", Text: "cm", Value: "cm", Order: 1, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "LengthUnit", Text: "inch", Value: "inch", Order: 2, IsEnabled: true})
	case "FontFamily":
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "FontFamily", Text: "Arial Unicode MS", Value: "Arial Unicode MS", Order: 1, IsEnabled: true})
		res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "FontFamily", Text: "Arial", Value: "Arial", Order: 2, IsEnabled: true})
	case "MWL_Modality":
		if product == common.PRODUCT_VET {
			res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "MWL_Modality", Text: "RF", Value: "RF", Order: 1, IsEnabled: true})
			res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "MWL_Modality", Text: "DX", Value: "DX", Order: 2, IsEnabled: true})
			res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "MWL_Modality", Text: "XA", Value: "XA", Order: 3, IsEnabled: true})
		} else if product == common.PRODUCT_DROS {
			res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "MWL_Modality", Text: "DX", Value: "DX", Order: 1, IsEnabled: true})
			res.ConfigOption = append(res.ConfigOption, &pb.ConfigOption{Flag: "MWL_Modality", Text: "CR", Value: "CR", Order: 2, IsEnabled: true})
		}
	default:
		return &res, status.Errorf(codes.NotFound, "flag %s not found", in.GetFlag())
	}
	return &res, nil
}
func (s *ConfigServer) ConfigList(ctx context.Context, in *pb.ConfigListRequest) (*pb.ConfigListResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method ConfigList not implemented")
}

//func GetConfigList() ([]*dto.ConfigResp, error) {
//	res := []*dto.ConfigResp{}
//	var items []*models.ConfigItem
//	query := models.DB.Model(&models.ConfigItem{})
//	err := query.Order("id").Find(&items).Error
//	if err != nil {
//		return res, err
//	}
//	for _, c := range items {
//		res = append(res, &dto.ConfigResp{
//			Key:         c.Key,
//			Value:       c.Value,
//			OptionKey:   c.OptionKey,
//			ValueType:   c.ValueType,
//			Description: c.Description,
//			Order:       c.Order,
//			IsEnabled:   c.IsEnabled,
//			Uri:         c.Uri,
//		})
//	}
//	return res, nil
//}
